# -*- coding: utf-8 -*-
"""Project metadata

Information describing the project.
"""

# The package name, which is also the "UNIX name" for the project.
package = 'terminator3'
project = "Terminator3"
project_no_spaces = project.replace(' ', '')
version = '0.0.1'
description = 'It does cool things'
authors = ['Foo Bar', 'John Doe']
authors_string = ', '.join(authors)
emails = ['foobar@example.com', 'johndoe@thisisfake.org']
license = 'MIT'
copyright = '2016 ' + authors_string
url = 'http://example.com/'
